Index: src/mainboard/thomson/ip1000/Kconfig
===================================================================
--- src/mainboard/thomson/ip1000/Kconfig	(revision 5220)
+++ src/mainboard/thomson/ip1000/Kconfig	(working copy)
@@ -9,7 +9,9 @@
 	select HAVE_PIRQ_TABLE
 	select UDELAY_TSC
 	select BOARD_ROMSIZE_KB_512
+	select HAVE_MAINBOARD_RESOURCES
 	select HAVE_SMI_HANDLER
+	select GFXUMA
 
 config MAINBOARD_DIR
 	string
Index: src/mainboard/thomson/ip1000/mainboard.c
===================================================================
--- src/mainboard/thomson/ip1000/mainboard.c	(revision 5220)
+++ src/mainboard/thomson/ip1000/mainboard.c	(working copy)
@@ -1,7 +1,7 @@
 /*
  * This file is part of the coreboot project.
  *
- * Copyright (C) 2008 Joseph Smith <joe@settoplinux.org>
+ * Copyright (C) 2008-2010 Joseph Smith <joe@settoplinux.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,15 @@
  */
 
 #include <device/device.h>
+#include <boot/tables.h>
+#include <arch/coreboot_tables.h>
 #include "chip.h"
 
+int add_mainboard_resources(struct lb_memory *mem)
+{
+	return add_northbridge_resources(mem);
+}
+
 static void mainboard_init(device_t dev)
 {
 	// TODO Switch parport LEDs again
Index: src/mainboard/rca/rm4100/Kconfig
===================================================================
--- src/mainboard/rca/rm4100/Kconfig	(revision 5220)
+++ src/mainboard/rca/rm4100/Kconfig	(working copy)
@@ -8,8 +8,10 @@
 	select ROMCC
 	select HAVE_PIRQ_TABLE
 	select UDELAY_TSC
-	select BOARD_ROMSIZE_KB_512
+	select BOARD_ROMSIZE_KB_1024
+	select HAVE_MAINBOARD_RESOURCES
 	select HAVE_SMI_HANDLER
+	select GFXUMA
 
 config MAINBOARD_DIR
 	string
Index: src/mainboard/rca/rm4100/mainboard.c
===================================================================
--- src/mainboard/rca/rm4100/mainboard.c	(revision 5220)
+++ src/mainboard/rca/rm4100/mainboard.c	(working copy)
@@ -1,7 +1,7 @@
 /*
  * This file is part of the coreboot project.
  *
- * Copyright (C) 2008 Joseph Smith <joe@settoplinux.org>
+ * Copyright (C) 2008-2010 Joseph Smith <joe@settoplinux.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,15 @@
  */
 
 #include <device/device.h>
+#include <boot/tables.h>
+#include <arch/coreboot_tables.h>
 #include "chip.h"
 
+int add_mainboard_resources(struct lb_memory *mem)
+{
+	return add_northbridge_resources(mem);
+}
+
 static void mainboard_init(device_t dev)
 {
 	// TODO Switch parport LEDs again
Index: src/northbridge/intel/i82830/raminit.c
===================================================================
--- src/northbridge/intel/i82830/raminit.c	(revision 5220)
+++ src/northbridge/intel/i82830/raminit.c	(working copy)
@@ -48,7 +48,7 @@
  * 0x0 for Refresh Disabled (Self Refresh)
  * 0x1 for Refresh interval 15.6 us for 133MHz
  * 0x2 for Refresh interval 7.8 us for 133MHz
- * 0x7 /* Refresh interval 128 Clocks. (Fast Refresh Mode)
+ * 0x7 for Refresh interval 128 Clocks. (Fast Refresh Mode)
  */
 #define RAM_COMMAND_REFRESH		0x1
 
Index: src/northbridge/intel/i82830/northbridge.c
===================================================================
--- src/northbridge/intel/i82830/northbridge.c	(revision 5220)
+++ src/northbridge/intel/i82830/northbridge.c	(working copy)
@@ -1,7 +1,7 @@
 /*
  * This file is part of the coreboot project.
  *
- * Copyright (C) 2008 Joseph Smith <joe@smittys.pointclark.net>
+ * Copyright (C) 2008-2010 Joseph Smith <joe@settoplinux.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <bitops.h>
+#include <boot/tables.h>
+#include <arch/coreboot_tables.h>
 #include "chip.h"
 #include "i82830.h"
 
@@ -88,6 +90,18 @@
 	return tolm;
 }
 
+/* IGD memory */
+uint64_t uma_memory_base=0, uma_memory_size=0;
+
+int add_northbridge_resources(struct lb_memory *mem)
+{
+	printk_debug("Adding IGD UMA memory area\n");
+	lb_add_memory_range(mem, LB_MEM_RESERVED,
+		uma_memory_base, uma_memory_size);
+
+	return 0;
+}
+
 #if CONFIG_WRITE_HIGH_TABLES==1
 #define HIGH_TABLES_SIZE 64	// maximum size of high tables in KB
 extern uint64_t high_tables_base, high_tables_size;
@@ -106,8 +120,10 @@
 
 		if (CONFIG_VIDEO_MB == 512) {
 			igd_memory = (CONFIG_VIDEO_MB);
+			printk_debug("%dKB IGD UMA\n", igd_memory >> 10);
 		} else {
 			igd_memory = (CONFIG_VIDEO_MB * 1024);
+			printk_debug("%dMB IGD UMA\n", igd_memory >> 10);
 		}
 
 		/* Get the value of the highest DRB. This tells the end of
@@ -116,8 +132,12 @@
 		 */
 		tomk = ((unsigned long)pci_read_config8(mc_dev, DRB + 3)) << 15;
 		tomk -= igd_memory;
-		printk_debug("Memory detected: %ldKB RAM\n", tomk);
 
+		/* For reserving UMA memory in the memory map */
+		uma_memory_base = tomk * 1024ULL;
+		uma_memory_size = igd_memory * 1024ULL;
+		printk_debug("Available memory: %ldKB\n", tomk);
+
 		/* Compute the top of low memory. */
 		tolmk = pci_tolm >> 10;
 		if (tolmk >= tomk) {
